@@ -70,7 +70,7 @@ get_maxfd() {
 // Linux >= 5.9 with glibc >= 2.34
 //
 // These platforms are known to support fcntl() with F_CLOSEM:
-// AIX, IRIX, NetBSD >= 2.0
+// AIX, NetBSD >= 2.0
 //
 // These platforms have getdirentries() and a "magic" directory with an entry
 // for each FD open in the current process:
@@ -220,7 +220,12 @@ Xapian::Internal::closefrom(int fd)
     // getdirentries() then this code can be used.  AIX is an example of
     // a platform of the former, but apparently has F_CLOSEM.
     char path[6 + sizeof(pid_t) * 3 + 4];
+# ifdef SNPRINTF
+    snprintf(path, sizeof(path), "/proc/%ld/fd", long(getpid()));
+    path[sizeof(path) - 1] = '\0';
+# else
     sprintf(path, "/proc/%ld/fd", long(getpid()));
+# endif
 #endif
     if (maxfd < 0)
 	maxfd = get_maxfd();
